@@ -34,6 +34,8 @@ pub struct Config {
     pub local_addr: SocketAddr,
     /// Path to local storage.
     pub root_dir: PathBuf,
+    /// Network's genesis key
+    pub genesis_key: bls::PublicKey,
     /// QuicP2p options.
     pub qp2p: QuicP2pConfig,
     /// The amount of time to wait for responses to queries before giving up and returning an error.
@@ -54,6 +56,7 @@ impl Config {
     pub async fn new(
         root_dir: Option<&Path>,
         local_addr: Option<SocketAddr>,
+        genesis_key: bls::PublicKey,
         config_file_path: Option<&Path>,
         query_timeout: Option<Duration>,
     ) -> Self {
@@ -70,23 +73,13 @@ impl Config {
         Self {
             local_addr: local_addr.unwrap_or_else(|| SocketAddr::from(DEFAULT_LOCAL_ADDR)),
             root_dir: root_dir.clone(),
+            genesis_key,
             qp2p,
             query_timeout: query_timeout.unwrap_or(DEFAULT_QUERY_TIMEOUT),
         }
     }
 }
 
-impl Default for Config {
-    fn default() -> Self {
-        Self {
-            local_addr: SocketAddr::from(DEFAULT_LOCAL_ADDR),
-            root_dir: default_dir(),
-            qp2p: Default::default(),
-            query_timeout: Default::default(),
-        }
-    }
-}
-
 async fn read_config_file(filepath: &Path) -> Result<QuicP2pConfig, Error> {
     debug!("Reading config file '{}' ...", filepath.display());
     let mut file = File::open(filepath).await?;
@@ -147,10 +140,18 @@ mod tests {
         let root_dir = temp_dir.path().to_path_buf();
         let cfg_filename: String = thread_rng().sample_iter(&Alphanumeric).take(15).collect();
         let config_filepath = root_dir.join(&cfg_filename);
+        let genesis_key = bls::SecretKey::random().public_key();
 
         // In the absence of a config file, the config handler
         // should initialize bootstrap_cache_dir only
-        let config = Config::new(Some(&root_dir), None, Some(&config_filepath), None).await;
+        let config = Config::new(
+            Some(&root_dir),
+            None,
+            genesis_key,
+            Some(&config_filepath),
+            None,
+        )
+        .await;
         // convert to string for assert
         let mut str_path = root_dir
             .to_str()
@@ -164,6 +165,7 @@ mod tests {
         let expected_config = Config {
             local_addr: (Ipv4Addr::UNSPECIFIED, 0).into(),
             root_dir: root_dir.clone(),
+            genesis_key,
             qp2p: QuicP2pConfig::default(),
             query_timeout: DEFAULT_QUERY_TIMEOUT,
         };
@@ -172,16 +174,14 @@ mod tests {
         create_dir_all(&root_dir).await?;
         let mut file = File::create(&config_filepath)?;
 
-        let config_on_disk = Config::default();
+        let config_on_disk =
+            Config::new(None, None, genesis_key, Some(&config_filepath), None).await;
         serde_json::to_writer_pretty(&mut file, &config_on_disk)?;
         file.sync_all()?;
 
-        let read_cfg = Config::new(None, None, Some(&config_filepath), None).await;
+        let read_cfg = Config::new(None, None, genesis_key, None, None).await;
         assert_eq!(config_on_disk, read_cfg);
 
-        let default_cfg = Config::new(None, None, None, None).await;
-        assert_eq!(Config::default(), default_cfg);
-
         Ok(())
     }
 }
